@@ -1,9 +1,7 @@
 try:
     from . import _lib as lib
-    from . import nutDb as db
 except:
     import _lib as lib
-    import nutDb as db
 os          = lib.os()
 dt          = lib.datetime()
 pd          = lib.pandas()
